import { f as GetUrlRequest$1, a as GetUrlResponse$1, g as GetPurchaseHistoryRequest$1, b as GetPurchaseHistoryResponse$1, j as GetMeteredBillingChargesRequest$1, k as GetMeteredBillingChargesResponse$1 } from './devcenter-checkout-v1-purchased-item-billing.universal-BOJl75V0.mjs';

interface PurchasedItem {
    /** ID of your app's paid plan. */
    productId?: string;
    /** Price of your app's paid plan. For example, `9.95`. */
    price?: string;
    /**
     * 3-letter currency code in
     * [ISO-4217 alphabetic](https://en.wikipedia.org/wiki/ISO_4217#Active_codes) format.
     */
    currency?: string;
    /** Information about the billing cycle for your app's paid plan. */
    billingCycle?: PaymentCycleWithLiterals;
    /**
     * Date and time the site onwers have purchased your app's paid plan in
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     */
    dateCreated?: Date | null;
}
declare enum PaymentCycle {
    NO_CYCLE = "NO_CYCLE",
    MONTHLY = "MONTHLY",
    YEARLY = "YEARLY",
    ONE_TIME = "ONE_TIME",
    TWO_YEARS = "TWO_YEARS",
    THREE_YEARS = "THREE_YEARS",
    FOUR_YEARS = "FOUR_YEARS",
    FIVE_YEARS = "FIVE_YEARS"
}
/** @enumType */
type PaymentCycleWithLiterals = PaymentCycle | 'NO_CYCLE' | 'MONTHLY' | 'YEARLY' | 'ONE_TIME' | 'TWO_YEARS' | 'THREE_YEARS' | 'FOUR_YEARS' | 'FIVE_YEARS';
interface GetUrlRequest {
    /**
     * ID of your app's paid plan to retrieve the Wix checkout URL for. Check your app's dashboard
     * for a list of your app's supported product IDs.
     */
    productId: string;
    /**
     * URL for the Wix checkout page. Redirect site owners to this URL after
     * they've successfully purchased a paid plan for your app.
     * @format WEB_URL
     */
    successUrl?: string | null;
    /**
     * Whether the checkout is for testing purposes only. Testing is mainly
     * relevant for in-app purchase flows. When `true`, Wix charges the site
     * owners an amount of `0.00`.
     */
    testCheckout?: boolean;
    /** Information about the paid plan's billing cycle. */
    billingCycle?: PaymentCycleWithLiterals;
    /**
     * 2-letter country code in
     * [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements)
     * format.
     *
     * Default: `"US"`
     */
    countryCode?: string | null;
    /**
     * 2-letter language code in
     * [ISO 639-1 alpha-2](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) format.
     *
     * Default: `"EN"`
     */
    languageCode?: string | null;
    /** Coupon code for the paid plan. Available only in case there is a discount. */
    couponCode?: string | null;
}
interface GetUrlResponse {
    /**
     * URL for the Wix checkout page.
     * @format WEB_URL
     */
    checkoutUrl?: string;
    /**
     * Token for the Wix checkout page. The token holds all data about the order
     * you're creating a checkout for.  It is [signed](),
     * so you can verify that it comes from Wix.
     */
    token?: string | null;
}
interface GetPurchaseHistoryRequest {
}
interface GetPurchaseHistoryResponse {
    /** Retrieved purchases the site owners have completed for you app. */
    purchases?: PurchasedItem[];
}
interface GetMeteredBillingChargesRequest {
    /**
     * 3-letter currency code in
     * [ISO-4217 alphabetic](https://en.wikipedia.org/wiki/ISO_4217#Active_codes) format.
     * @format CURRENCY
     */
    currency?: string | null;
    /**
     * Start of the period you want to retrieve the custom charges for in
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     */
    startDate?: Date | null;
    /**
     * End of the period you want to retrieve the custom charges for in
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     */
    endDate?: Date | null;
}
interface GetMeteredBillingChargesResponse {
    /** List of retrieved custom charges. */
    charges?: Charge[];
}
interface Charge {
    /** ID of the custom charge. The ID consists of 64 characters. */
    id?: string | null;
    /** Description of the custom charge. */
    description?: string;
    /**
     * Charge amount.
     *
     * Min: `0.50`
     * @format DECIMAL_VALUE
     * @decimalValue options { gt:0.00 }
     */
    amount?: string;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getUrl(): __PublicMethodMetaInfo<'POST', {}, GetUrlRequest$1, GetUrlRequest, GetUrlResponse$1, GetUrlResponse>;
declare function getPurchaseHistory(): __PublicMethodMetaInfo<'GET', {}, GetPurchaseHistoryRequest$1, GetPurchaseHistoryRequest, GetPurchaseHistoryResponse$1, GetPurchaseHistoryResponse>;
declare function getMeteredBillingCharges(): __PublicMethodMetaInfo<'GET', {}, GetMeteredBillingChargesRequest$1, GetMeteredBillingChargesRequest, GetMeteredBillingChargesResponse$1, GetMeteredBillingChargesResponse>;

export { type __PublicMethodMetaInfo, getMeteredBillingCharges, getPurchaseHistory, getUrl };
