import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { G as GetUrlOptions, a as GetUrlResponse, b as GetPurchaseHistoryResponse, c as GetMeteredBillingChargesOptions, d as GetMeteredBillingChargesResponse, P as PurchasedItemInvoiceStatusUpdatedEnvelope } from './devcenter-checkout-v1-purchased-item-billing.universal-0VctJpJS.mjs';
export { B as BaseEventMetadata, m as Charge, C as ChargeOverride, l as GetMeteredBillingChargesRequest, i as GetPurchaseHistoryRequest, j as GetSitePaymentMethodsStatusRequest, k as GetSitePaymentMethodsStatusResponse, h as GetUrlRequest, n as IdentificationData, o as IdentificationDataIdOneOf, I as InvoiceStatus, g as InvoiceStatusUpdated, M as MessageEnvelope, e as PaymentCycle, f as PurchasedItem, W as WebhookIdentityType } from './devcenter-checkout-v1-purchased-item-billing.universal-0VctJpJS.mjs';

declare function getUrl$1(httpClient: HttpClient): GetUrlSignature;
interface GetUrlSignature {
    /**
     * Retrieves the URL for a Wix checkout page for the specified paid plan of your app.
     *
     *
     * This call succeeds only in case you have previously
     * [set up an external pricing page in your app's dashboard](https://dev.wix.com/docs/build-apps/build-your-app/pricing-plans/set-up-an-external-pricing-page).
     *
     * The returned checkout URL is valid for 48 hours.
     *
     * This API allows your app to manage your pricing page outside of Wix while
     * still using the standard Wix checkout flow.
     * @param - ID of your app's paid plan to retrieve the Wix checkout URL for. Check your app's dashboard
     * for a list of your app's supported product IDs.
     */
    (productId: string, options?: GetUrlOptions | undefined): Promise<GetUrlResponse>;
}
declare function getPurchaseHistory$1(httpClient: HttpClient): GetPurchaseHistorySignature;
interface GetPurchaseHistorySignature {
    /**
     * Retrieves a list of the site owner's past purchases for your app.
     *
     *
     * You don't have to explicitly pass an identifier for the Wix site as part of
     * the request, since this information is taken automatically from the context.
     *
     * The response doesn't include any details about cancellations.
     */
    (): Promise<GetPurchaseHistoryResponse>;
}
/** @internal */
declare function getMeteredBillingCharges$1(httpClient: HttpClient): GetMeteredBillingChargesSignature;
interface GetMeteredBillingChargesSignature {
    /**
     * Triggers Wix to call the
     * [List Custom Charges SPI](https://dev.wix.com/docs/rest/internal-only/premium/custom-charges-spi/custom-charges-provider-v1/list-charges).
     *
     *
     * Wix doesn't use the response from _List Charges_ SPI to actually create an
     * invoice that's sent to the customer. Instead, calling _Get Metered Billing Charges_
     * allows you confirm that your integration with the Custom Charges SPI is
     * working as intended.
     */
    (options?: GetMeteredBillingChargesOptions | undefined): Promise<GetMeteredBillingChargesResponse>;
}
declare const onPurchasedItemInvoiceStatusUpdated$1: EventDefinition<PurchasedItemInvoiceStatusUpdatedEnvelope, "InvoiceStatusUpdated">;

declare const getUrl: MaybeContext<BuildRESTFunction<typeof getUrl$1> & typeof getUrl$1>;
declare const getPurchaseHistory: MaybeContext<BuildRESTFunction<typeof getPurchaseHistory$1> & typeof getPurchaseHistory$1>;
/** @internal */
declare const getMeteredBillingCharges: MaybeContext<BuildRESTFunction<typeof getMeteredBillingCharges$1> & typeof getMeteredBillingCharges$1>;
/**
 * Triggered when there is an update to the payment status of an invoice.
 * Charges made using the [Custom Charges SPI](https://dev.wix.com/docs/rest/app-management/app-billing/custom-charges-service-plugin/introduction) may be based on usage.
 * Learn more about [usage-based charges](https://dev.wix.com/docs/build-apps/launch-your-app/pricing-and-billing/set-up-a-usage-based-business-model).
 */
declare const onPurchasedItemInvoiceStatusUpdated: BuildEventDefinition<typeof onPurchasedItemInvoiceStatusUpdated$1>;

export { GetMeteredBillingChargesOptions, GetMeteredBillingChargesResponse, GetPurchaseHistoryResponse, GetUrlOptions, GetUrlResponse, PurchasedItemInvoiceStatusUpdatedEnvelope, getMeteredBillingCharges, getPurchaseHistory, getUrl, onPurchasedItemInvoiceStatusUpdated };
